import {Component, inject, OnInit} from '@angular/core';
import {ActivatedRoute, Router} from "@angular/router";
import {TodoService} from "../service/todo.service";
import {FormBuilder, FormGroup, ReactiveFormsModule, Validators} from "@angular/forms";

@Component({
  selector: 'app-edit',
  imports: [
    ReactiveFormsModule
  ],
  templateUrl: './edit.component.html',
  styleUrl: './edit.component.css'
})
export default class EditComponent implements OnInit{
  private id!: number;
  private todoService: TodoService = inject(TodoService);
  private route: ActivatedRoute = inject(ActivatedRoute);
  private fb: FormBuilder = inject(FormBuilder);
  public form!: FormGroup;


  ngOnInit() {
    this.id = parseInt(this.route.snapshot.paramMap.get('id') ?? '', 10);

    const old = this.todoService.getOne(this.id);
    this.form = this.fb.group({
      title: ['', Validators.required],
      dueDate: ['', Validators.required],
    });

    old.subscribe((old => {
      this.form.patchValue({
        title: old.title,
        dueDate: old.dueDate,
      })
    }))
  }

  edit() {
    const edited = this.form.value as { title: string, dueDate: Date };

    this.todoService.edit(edited, this.id).subscribe(() => this.todoService.todos.reload());
  }
}
