import {inject, Injectable} from "@angular/core";
import {HttpClient} from "@angular/common/http";
import {Observable} from "rxjs";
import {GetTask, PutTask} from "../dto/models";
import {rxResource} from "@angular/core/rxjs-interop";


@Injectable({
  providedIn: 'root'
})
export class TodoService {
  http: HttpClient = inject(HttpClient);

  _todos = rxResource({
    stream: () => this.getTodos(),
  })

  public get todos() {
    return this._todos;
  }

  public getTodos(): Observable<GetTask[]> {
    return this.http.get<GetTask[]>('http://localhost:2000/api/tasks');
  }

  public create(todo: {title: string, dueDate: Date}) {
    return this.http.post('http://localhost:2000/api/tasks', todo);
  }

  public markAsDone(todo: GetTask) {
    const putTask: PutTask = {
      title: todo.title,
      dueDate: todo.dueDate,
      done: true,
    }

    return this.http.put(`http://localhost:2000/api/tasks/${todo.id}`, putTask);
  }

  public delete(id: number) {
    return this.http.delete(`http://localhost:2000/api/tasks/${id}`);
  }

  edit(edited: { title: string; dueDate: Date }, id: number) {
    return this.http.put(`http://localhost:2000/api/tasks/${id}`, edited);
  }

  getOne(id: number) {
    return this.http.get<GetTask>(`http://localhost:2000/api/tasks/${id}`);
  }
}
